'''
MIT License

Copyright (c) 2023 Fast Data Science Ltd (https://fastdatascience.com)

Maintainer: Thomas Wood

Tutorial at https://fastdatascience.com/drug-named-entity-recognition-python-library/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

common_english_words_to_include_in_drugs_dictionary = {
    "absinthium",
    "acetphenetidin",
    "acetylsalicylate",
    "acocantherin",
    "actinomycin",
    "adrenalone",
    "adrenergic",
    "aerosporin",
    "aloe",
    "amidopyrine",
    "aminopyrine",
    "amphetamine",
    "analeptic",
    "analgesic",
    "andrographolide",
    "anesthetic",
    "angelica",
    "anorectic",
    "antacid",
    "anthelmintic",
    "antiasthmatic",
    "antibiotic",
    "anticholinergic",
    "antidiabetic",
    "antiemetic",
    "antiepileptic",
    "antifibrinolysin",
    "antihemorrhagic",
    "antihistamine",
    "antimalarial",
    "antiparasitic",
    "antipruritic",
    "antipyretic",
    "antispasmodic",
    "apomorphine",
    "arbutin",
    "arecoline",
    "aspirin",
    "atebrin",
    "atropine",
    "aureomycin",
    "bacitracin",
    "barbital",
    "barbitone",
    "barosmin",
    "belladonna",
    "benzocaine",
    "benzofuran",
    "benzoin",
    "benzylpenicillin",
    "berbamine",
    "betulin",
    "bicarbonate",
    "biguanide",
    "bioral",
    "biotin",
    "bismuth",
    "boldo",
    "borneol",
    "bronchodilator",
    "butyrolactone",
    "calamus",
    "camphor",
    "cannabinol",
    "cantharidin",
    "carbamate",
    "carbostyril",
    "carbromal",
    "cardiotonic",
    "catechu",
    "cathine",
    "cevadine",
    "chelerythrine",
    "chinin",
    "chloral",
    "chloramphenicol",
    "chloroform",
    "chloroquine",
    "cholinergic",
    "cholinesterase",
    "cinchonidine",
    "cinchophen",
    "cineole",
    "cinnamaldehyde",
    "citrate",
    "clavacin",
    "cocaine",
    "codeine",
    "colchicine",
    "conquinine",
    "convulsant",
    "copal",
    "cortisone",
    "coumarin",
    "curare",
    "curcumin",
    "cycloplegic",
    "cymene",
    "cystamine",
    "diamorphine",
    "dicoumarin",
    "digitoxin",
    "ecstasy",
    "elecampane",
    "emend",
    "emetine",
    "ephedrine",
    "epinephrine",
    "epinine",
    "ergometrine",
    "ergonovine",
    "ergotamine",
    "ergotaminine",
    "erythrosin",
    "esculin",
    "estrogen",
    "ethylenediamine",
    "ethylmorphine",
    "eucaine",
    "eucalyptol",
    "eugenol",
    "excipient",
    "expectorant",
    "factive",
    "fenchone",
    "fibrinolysin",
    "flagroot",
    "flector",
    "forane",
    "gallotannin",
    "ginkgo",
    "ginseng",
    "glycyrrhizin",
    "goldenseal",
    "gonadotropin",
    "guaiac",
    "guanidine",
    "guvacine",
    "harmaline",
    "heparin",
    "heroin",
    "hexamethylenamine",
    "hexylresorcinol",
    "histamine",
    "hyaluronidase",
    "hydramine",
    "hydrochloride",
    "hydrogel",
    "hydroquinine",
    "hydroquinone",
    "hyoscine",
    "hyoscyamine",
    "hypericin",
    "hypoglycemic",
    "indazole",
    "indirubin",
    "insulin",
    "inula",
    "isatin",
    "isocodeine",
    "isomeride",
    "isorhodeose",
    "isoxazole",
    "karaya",
    "licorice",
    "lithium",
    "luminal",
    "lustral",
    "mannose",
    "marijuana",
    "methadone",
    "methemoglobin",
    "methenamine",
    "methylamine",
    "morphia",
    "morphine",
    "myrrh",
    "narcotic",
    "nikethamide",
    "nitroglycerin",
    "nitroprusside",
    "olibanum",
    "opium",
    "ouabain",
    "oxyquinoline",
    "oxytocic",
    "palladia",
    "paludrin",
    "paludrine",
    "papaverine",
    "paraderm",
    "paraldehyde",
    "parasiticide",
    "paregoric",
    "penicillin",
    "pentobarbital",
    "peppermint",
    "phenacetin",
    "phenazone",
    "phenetidine",
    "phenobarbital",
    "phenothiazine",
    "physostigmine",
    "picropodophyllin",
    "picrotoxin",
    "pilocarpine",
    "piperazine",
    "podophyllin",
    "propolis",
    "protamine",
    "pseudoephedrine",
    "pseudotropine",
    "psyllium",
    "pyrazole",
    "pyridoxine",
    "pyruvaldehyde",
    "quercetin",
    "quinacrine",
    "quinate",
    "quinazoline",
    "quinidine",
    "quinina",
    "quinine",
    "quinoxaline",
    "rattleroot",
    "rhein",
    "rotenone",
    "safrole",
    "salicylamide",
    "salix",
    "salol",
    "santonin",
    "scopolamine",
    "senega",
    "sinomenine",
    "snakeroot",
    "sparteine",
    "spasmolytic",
    "stilbestrol",
    "stilboestrol",
    "streptomycin",
    "strychnin",
    "strychnine",
    "sulfadiazine",
    "sulfaguanidine",
    "sulfamerazine",
    "sulfamethazine",
    "sulfamethylthiazole",
    "sulfanilamide",
    "sulfapyridine",
    "sulfaquinoxaline",
    "sulfathiazole",
    "sympatholytic",
    "sympathomimetic",
    "tenuate",
    "theophylline",
    "thiouracil",
    "thymol",
    "thymoquinone",
    "thyroglobulin",
    "tragacanth",
    "tramal",
    "trental",
    "trichloroethylene",
    "trinitrotoluene",
    "triterpene",
    "tryptophan",
    "tyramine",
    "usnea",
    "valerone",
    "vasoconstrictor",
    "vasodilator",
    "veratrine",
    "vermifuge",
    "wormwood",
    "xanthopterin",
    "yajeine",
    "yohimbine",
    "glycyrrhiza"
}

extra_terms_to_exclude_from_drugs_dictionary = {
    "black lead",
    "mineral carbon",
    "natural graphite",
    "whole blood",
    "oxygen therapy",
    "mandarin peel",
    "pomegranate fruit",
    "green tea",
    "gold leaf",
    "gold powder",
    "patent blue",
    "horse chestnut",
    "blue x",
    "dry ice",
    "macadamia nut",
    "brussels sprout",
    "beet sugar",
    "cane sugar",
    "table sugar",
    "white sugar",
    "kiwi fruit",
    "bilberry fruit",
    "bullhead fruit",
    "caltrop fruit",
    "tribulus fruit",
    "green tea",
    "pomegranate fruit",
    "schisandra fruit",
    "forsythia fruit",
    "garcinia fruit",
    "paraguay tea",
    "mace fruit",
    "nutmeg fruit",
    "cashew fruit",
    "java tea",
    "kidney tea",
}

extra_mappings = {"mounjaro": "tirzepatide"}